@@ -5,7 +5,7 @@ import zmq
 from pydantic import ValidationError, BaseModel
 from typing import Union, Optional, Callable, DefaultDict, List, Dict, TypeVar, Type, Generic
 
-from openmodule.models import ZMQMessage
+from openmodule.models.base import ZMQMessage
 
 
 class Listener:
