@@ -9,7 +9,7 @@ from pydantic import ValidationError, BaseModel
 from pydantic.main import ROOT_KEY
 
 from openmodule.messaging import get_sub_socket, get_pub_socket, receive_message_from_socket
-from openmodule.models import ZMQMessage
+from openmodule.models.rpc import RPCResponse, RPCRequest
 from openmodule.rpc.common import channel_to_request_topic, channel_to_response_topic
 from openmodule.threading import get_thread_wrapper
 
@@ -17,14 +17,6 @@ CallbackEntry = namedtuple("CallbackEntry", ["timestamp", "result"])
 HandlerEntry = namedtuple("HandlerEntry", ["request_class", "response_class", "handler"])
 
 
-class RPCRequest(ZMQMessage):
-    rpc_id: UUID
-    request: Optional[Dict]
-
-
-class RPCResponse(ZMQMessage):
-    rpc_id: Optional[UUID]
-    response: Any
 
 
 def gateway_filter(gate=None, direction=None):
