@@ -1,8 +1,7 @@
 import logging
-from enum import Enum
 
 from openmodule.dispatcher import EventListener, MessageDispatcher
-from openmodule.models import ZMQMessage
+from openmodule.models.base import ZMQMessage
 
 
 class ConnectionStatusMessage(ZMQMessage):
