@@ -3,6 +3,8 @@ import time
 from threading import Thread
 from unittest import TestCase
 
+from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
+
 from openmodule.config import database_folder
 from openmodule.database.database import Database, active_databases, database_name
 from openmodule.utils.db_helper import update_query, delete_query
@@ -129,6 +131,33 @@ class DatabaseTest(SQLiteTestMixin, TestCase):
         self.assertIn("already exists", str(e.exception))
         self.assertTrue(os.path.exists(os.path.join(database_folder(), "asdf.sqlite3")))
 
+    def test_get(self):
+        with self.database as db:
+            base = db.query(DatabaseTestModel)
+            res = base.get("asdf")
+            self.assertIsNone(res)
+
+            with self.assertRaises(Exception) as e:
+                base.one()
+            self.assertEqual(NoResultFound, type(e.exception))
+
+            res = base.one_or_none()
+            self.assertIsNone(res)
+
+            res = base.first()
+            self.assertIsNone(res)
+
+            model1 = DatabaseTestModel()
+            model2 = DatabaseTestModel()
+            db.add(model1)
+            db.add(model2)
+
+            res = base.first()
+            self.assertIsNotNone(res)
+
+            with self.assertRaises(Exception) as e:
+                base.one_or_none()
+            self.assertEqual(MultipleResultsFound, type(e.exception))
 
 class ShutdownTestCase(TestCase):
     alembic_path = "../tests/test_database_data"
