@@ -4,7 +4,7 @@ from uuid import uuid4
 
 from pydantic.types import conint
 
-from openmodule.models import OpenModuleModel
+from openmodule.models.base import OpenModuleModel
 from openmodule.rpc import server
 from openmodule.rpc.common import channel_to_response_topic, channel_to_request_topic
 from openmodule.rpc.server import RPCServer, RPCRequest
